# image-analysis
Python-based software for XRD data analysis. Allows users to analyze SPEC data, raw XRD scan images, and reciprocal space-converted datasets.

## Roadmap for v0.1.0
- [ ] ImageView functionality
- [ ] RawDataController
- [ ] GriddedDataController
- [ ] ROIWidget workflow -> UI design -> functionality
- [ ] Curve class
- [ ] PlotView workflow -> UI design -> functionality
- [ ] Testing
- [ ] Documentation
- [ ] Prepare for v0.1.0 release

## License
See [`LICENSE.txt`](https://github.com/henryjsmith12/image-analysis/blob/main/LICENSE) for more information.

## Author
[Henry Smith](https://www.linkedin.com/in/henry-smith-5956a0189/) - Co-op Student Technical at Argonne National Laboratory